/*
* v2.1
* fixed first page tracking
*/
var _gaq;
var gtag;
var gtagValue = 'G-5KZG22E9VH'
window.dataLayer = window.dataLayer || [];

function gtag(){dataLayer.push(arguments);}

if (!gaanonym || !gaanonym.switcher || !gaanonym.switcher.isActive()) {
    gtag('consent', 'default', {
        'ad_storage': 'denied',
        'analytics_storage': 'denied'
    });
} else {
    gtag('consent', 'update', {
        'ad_storage': 'granted',
        'analytics_storage': 'granted'
    });
}
gtag('js', new Date());
gtag('config', gtagValue);

function initTracking(accId, cat_id, device) {
    initGtagTracking(accId, cat_id, device);
}

function initGtagTracking(accId, cat_id, device) {
    (function () {
        var _gtag = document.createElement('script');
        _gtag.type = 'text/javascript';
        _gtag.async = true;
        _gtag.src = 'https://www.googletagmanager.com/gtag/js?id=' + gtagValue;
        var s = document.getElementsByTagName('script')[0];
        s.parentNode.insertBefore(_gtag, s);
        gtag('event',
            'setCustomVar',
            {
                dimension1: 'catalogue_id',
                dimension2: cat_id
            });
        gtag('event',
            'setCustomVar',
            {
                dimension1: 'device',
                dimension2: device
            });
        gtag('event',
            'setAccount',
            {
                dimension1: accId,
            });

    })();
}

//Create module p2fTracking
var p2fTracking = (function () {

    var module = {};

    var cat_id = '-1',
        device = '-1',
        accId = gtagValue,
        stackTrack1,
        stackTrack2,
        appTrackingIsReady;

    function statLog(text) {
        // console.log(text);
    }

    function getTrackingServiceName() {
        return "GTAG";
    }

    function checkStatus(element) {
        gaanonym.switcher.checkStatus(element);
    }

    function activate() {
        gtag('consent', 'update', {
            'ad_storage': 'granted',
            'analytics_storage': 'granted'
        });
        gaanonym.switcher.activate();
        initGtagTracking();
    }

    function deactivate() {
        gtag('consent', 'default', {
            'ad_storage': 'denied',
            'analytics_storage': 'denied'
        });
        gaanonym.switcher.deactivate();
        statLog("deactivated tracking");
    }

    function isActive() {
        return gaanonym.switcher.isActive();
    }

    /*### Tracking-Events ###*/

    /*Wird mit jedem Blättern exakt einmal aufgerufen.
    Wenn z.B. Seite 2 & 3 angezeigt werden,  so wird 2
    und 3 als Parameter übergeben. Wird nur eine Seite
    angezeigt, so bleibt der zweite Parameter NULL oder '' */

    function trackFlipped(page1Index, page2Index) {
        if (typeof gaanonym !== 'undefined' && gaanonym.switcher.isActive()) {
            if (gtag) {
                if (page2Index && Number(page2Index)) {
                    gtag('event',
                        'page_view',
                        {
                            dimension1: page1Index,
                            dimension2: '+',
                        });
                    gtag('event',
                        'page_view',
                        {
                            dimension1: page2Index,
                            dimension2: '-',
                        });
                    // _gaq.push(['_trackPageview', page1Index + '+'], ['_trackPageview', page2Index + '-']);
                    statLog("flipped page " + page1Index + '+ and ' + page2Index + '-');
                } else if (page1Index && Number(page1Index)) {
                    gtag('event',
                        'page_view',
                        {
                            dimension1: page1Index,
                            dimension2: '',
                        });
                    // _gaq.push(['_trackPageview', page1Index + '']);
                    statLog("flipped page " + page1Index);
                }
            } else {
                if (page2Index && Number(page2Index)) {
                    stackTrack1 = page1Index;
                    stackTrack2 = page2Index;
                    statLog("put in stack " + page1Index + ' and ' + page2Index);
                } else {
                    stackTrack1 = page1Index;
                    stackTrack2 = null;
                    statLog("put in stack " + page1Index);
                }
            }
        }
    }

    function initGtagTracking() {
        initTracking(accId, cat_id, device);
        statLog("initialized tracking. device: " + device + ", catalog: " + cat_id + ", GA account: " + accId + ", active: " + gaanonym.switcher.isActive());
    }

    /* Init tracking */
    function trackCatalogLoaded(catalog_id, p_device) {
        cat_id = catalog_id;
        device = p_device;
        if (typeof gaanonym !== 'undefined' && gaanonym.switcher.isActive()) {
            initGtagTracking();
            //check if flippedPages in Stack an commit
            if (stackTrack1 && stackTrack2) {
                trackFlipped(stackTrack1, stackTrack2);
                stackTrack1 = null;
                stackTrack2 = null;
            } else if (stackTrack1) {
                trackFlipped(stackTrack1, null);
                stackTrack1 = null;
            }
        }
    }

    /*Wird bei jedem ERSTMALIGEN Zoom einer Seite aufgerufen.
    Bei Doppelseitenzoom werden zwei Parameter übergegeben,
    bei einseitigem Zoom bleibt der zweite Paramter NULL oder '' */

    function trackZoom(page1Index, page2Index) {
        if (typeof gaanonym !== 'undefined' && gaanonym.switcher.isActive()) {
            if (page2Index && Number(page2Index)) {
                gtag('event',
                    'pageZoomed',
                    {
                        dimension1: page1Index,
                        dimension2: '',
                    });
                gtag('event',
                    'pageZoomed',
                    {
                        dimension1: page2Index,
                        dimension2: '',
                    });
                // _gaq.push(['_trackEvent', 'pageZoomed', page1Index + ''], ['_trackEvent', 'pageZoomed', page2Index + '']);
                statLog("zoomed page " + page1Index + " and " + page2Index);
            } else {
                gtag('event',
                    'pageZoomed',
                    {
                        dimension1: page1Index,
                        dimension2: '',
                    });
                // _gaq.push(['_trackEvent', 'pageZoomed', page1Index + '']);
                statLog("zoomed page " + page1Index);
            }
        }
    }

    /* Wird aufgerufen, wenn von einem Hotspot die
    Detailansicht aufgerufen wird.
    Wird in der HTMLT5 Version nicht genutzt */

    function trackHotspotShown(hotspotId, type, label) {
        if (typeof gaanonym !== 'undefined' && gaanonym.switcher.isActive()) {
            gtag('event',
                'hotspotShown',
                {
                    dimension1: hotspotId,
                    dimension2: '',
                });
            // _gaq.push(['_trackEvent', 'hotspotShown', hotspotId + '']);
            statLog("opened hotspot: " + hotspotId + " of type: " + type + " with label: " + label);
        }
    }

    /* Aufruf beim Clicken auf den Hotspot */

    function trackHotspotClicked(hotspotId, type, label) {
        if (typeof gaanonym !== 'undefined' && gaanonym.switcher.isActive()) {
            gtag('event',
                'hotspotClicked',
                {
                    dimension1: hotspotId,
                    dimension2: '',
                });
            // _gaq.push(['_trackEvent', 'hotspotClicked', hotspotId + '']);
            statLog("clicked hotspot: " + hotspotId + " of type: " + type + " with label: " + label);
        }
    }

    /* Jede Suche löst ein trackSearch-Event aus.
    Übergeben wird der Suchbegriff und die Anzahl
    der Treffer */

    function trackSearch(phrase, resultsCount) {
        if (typeof gaanonym !== 'undefined' && gaanonym.switcher.isActive()) {
            gtag('event',
                'search',
                {
                    dimension1: phrase,
                    dimension2: resultsCount,
                    dimension3: ''
                });
            // _gaq.push(['_trackEvent', 'search', phrase, resultsCount + '']);
            statLog("searched for: " + phrase + ", got " + resultsCount + " results");
        }
    }

    /* Aufruf beim Einzelseiten- oder Gesamtdownload.
    Bei Einzelseiten bleibt der zweite Parameter NULL */

    function trackDownload(fromIndex, toIndex) {
        if (typeof gaanonym !== 'undefined' && gaanonym.switcher.isActive()) {
            if (toIndex) {
                gtag('event',
                    'downloaded',
                    {
                        dimension1: fromIndex,
                        dimension2: ',',
                        dimension3: toIndex
                    });
                // _gaq.push(['_trackEvent', 'downloaded', fromIndex + ',' + toIndex]);
                statLog("downloaded from page " + fromIndex + " to " + toIndex);
            } else {
                gtag('event',
                    'downloaded',
                    {
                        dimension1: fromIndex,
                        dimension2: '',
                    });
                // _gaq.push(['_trackEvent', 'downloaded', fromIndex + '']);
                statLog("downloaded page " + fromIndex);
            }
        }
    }

    /* Aufruf beim Drucken von Seiten.
    Bei Einzelseiten bleibt der zweite Parameter NULL */

    function trackPrint(fromIndex, toIndex) {
        if (typeof gaanonym !== 'undefined' && gaanonym.switcher.isActive()) {
            if (toIndex) {
                gtag('event',
                    'printed',
                    {
                        dimension1: fromIndex,
                        dimension2: ',',
                        dimension3: toIndex
                    });
                // _gaq.push(['_trackEvent', 'printed', fromIndex + ',' + toIndex]);
                statLog("printed from page " + fromIndex + " to " + toIndex);
            } else {
                gtag('event',
                    'printed',
                    {
                        dimension1: fromIndex,
                        dimension2: '',
                    });
                // _gaq.push(['_trackEvent', 'printed', fromIndex + '']);
                statLog("printed page " + fromIndex);
            }
        }
    }

    /* Aufruf beim Öffnen des Inhaltsverzeichnisses. */

    function trackToc() {
        if (typeof gaanonym !== 'undefined' && gaanonym.switcher.isActive()) {
            gtag('event',
                'toc',
                {
                    dimension1: fromIndex,
                    dimension2: ' ',
                });
            // _gaq.push(['_trackEvent', 'toc', ' ']);
            statLog("clicked toc");
        }
    }

    /* Aufruf beim Favorisieren von Seiten. */

    function trackFavorite(pageIndex) {
        if (typeof gaanonym !== 'undefined' && gaanonym.switcher.isActive()) {
            gtag('event',
                'favorited',
                {
                    dimension1: pageIndex,
                    dimension2: '',
                });
            // _gaq.push(['_trackEvent', 'favorited', pageIndex + '']);
            statLog("favorited page: " + pageIndex);
        }
    }

    /* Aufruf beim Teilen von Seiten. */

    function trackShare(service) {
        if (typeof gaanonym !== 'undefined' && gaanonym.switcher.isActive()) {
            gtag('event',
                'shared',
                {
                    dimension1: service,
                });
            // _gaq.push(['_trackEvent', 'shared', service]);
            statLog("shared on: " + service);
        }
    }

    /* Aufruf beim Vergleichen von Seiten. */

    function trackPageComp(page1Index, page2Index) {
        if (typeof gaanonym !== 'undefined' && gaanonym.switcher.isActive()) {
            gtag('event',
                'pageCompared',
                {
                    dimension1: page1Index,
                    dimension2: ''
                });
            gtag('event',
                'pageCompared',
                {
                    dimension1: page2Index,
                    dimension2: ''
                });
            // _gaq.push(['_trackEvent', 'pageCompared', page1Index + ''], ['_trackEvent', 'pageCompared', page2Index + '']);
            statLog("compared page " + page1Index + " and " + page2Index);
        }
    }

    /*
     * Export
     */

    module.getTrackingServiceName = function () {
        return getTrackingServiceName();
    };
    module.checkStatus = function (element) {
        return checkStatus(element);
    };
    module.activate = function () {
        return activate();
    };
    module.deactivate = function () {
        return deactivate();
    };
    module.isActive = function () {
        return isActive();
    };
    module.trackFlipped = function (page1Index, page2Index) {
        return trackFlipped(page1Index, page2Index);
    };
    module.initGtagTracking = function () {
        return initGtagTracking();
    };
    module.trackCatalogLoaded = function (catalog_id, p_device) {
        return trackCatalogLoaded(catalog_id, p_device);
    };
    module.trackZoom = function (page1Index, page2Index) {
        return trackZoom(page1Index, page2Index);
    };
    module.trackHotspotShown = function (hotspotId, type, label) {
        return trackHotspotShown(hotspotId, type, label);
    };
    module.trackHotspotClicked = function (hotspotId, type, label) {
        return trackHotspotClicked(hotspotId, type, label);
    };
    module.trackSearch = function (phrase, resultsCount) {
        return trackSearch(phrase, resultsCount);
    };
    module.trackDownload = function (fromIndex, toIndex) {
        return trackDownload(fromIndex, toIndex);
    };
    module.trackPrint = function (fromIndex, toIndex) {
        return trackPrint(fromIndex, toIndex);
    };
    module.trackToc = function () {
        return trackToc();
    };
    module.trackFavorite = function (pageIndex) {
        return trackFavorite(pageIndex);
    };
    module.trackShare = function (service) {
        return trackShare(service);
    };
    module.trackPageComp = function (page1Index, page2Index) {
        return trackPageComp(page1Index, page2Index);
    };

    return module;

}());
